# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import BatchTestRunEventClass
from .....schema_classes import BatchTestRunResultClass
from .....schema_classes import BatchTestRunStatusClass
from .....schema_classes import TestActionsErrorClass
from .....schema_classes import TestActionsReportClass
from .....schema_classes import TestDefinitionClass
from .....schema_classes import TestDefinitionTypeClass
from .....schema_classes import TestInfoClass
from .....schema_classes import TestIntervalClass
from .....schema_classes import TestModeClass
from .....schema_classes import TestReportClass
from .....schema_classes import TestResultClass
from .....schema_classes import TestResultTypeClass
from .....schema_classes import TestResultsClass
from .....schema_classes import TestScheduleClass
from .....schema_classes import TestSourceClass
from .....schema_classes import TestSourceTypeClass
from .....schema_classes import TestStatusClass


BatchTestRunEvent = BatchTestRunEventClass
BatchTestRunResult = BatchTestRunResultClass
BatchTestRunStatus = BatchTestRunStatusClass
TestActionsError = TestActionsErrorClass
TestActionsReport = TestActionsReportClass
TestDefinition = TestDefinitionClass
TestDefinitionType = TestDefinitionTypeClass
TestInfo = TestInfoClass
TestInterval = TestIntervalClass
TestMode = TestModeClass
TestReport = TestReportClass
TestResult = TestResultClass
TestResultType = TestResultTypeClass
TestResults = TestResultsClass
TestSchedule = TestScheduleClass
TestSource = TestSourceClass
TestSourceType = TestSourceTypeClass
TestStatus = TestStatusClass

# fmt: on
